==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Kimlik doğrulama zaman aşımı</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk meşgul olduğundan şu anda ayrılamıyor</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk meşgul, şimdi çıkartılamıyor</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Aygıt meşgul, şimdi çıkarılamıyor</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Aygıt meşgul, şimdi çıkarılamaz</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Birim</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Bilinmiyor</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Cihaz güvenli bir şekilde kaldırılmadı</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Bir daha ki sefer &quot;Güvenle Kaldıra&quot; tıklayın bağlantısını kesin</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Aygıt meşgul, şimdi çıkarılamıyor</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Aygıt meşgul, şimdi çıkarılamaz</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Aygıtın bağı ayrılamadı</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Diski &quot;%1&quot; kullanıcısı bağlamış, siz bu bağı ayıramazsınız.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Takılı aygıt bulunamıyor</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Diskler</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Tümünü çıkar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Cihaz güvenli bir şekilde kaldırıldı</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Erişim reddedildi</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Bu klasöre erişme izniniz yok</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Cihaz taranıyor, durdurulsun mu?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.1.orig.tar.xz: dde-file-manager-5.8.1/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Kimlik doğrulama zaman aşımı</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk meşgul olduğundan şu anda ayrılamıyor</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk meşgul, şimdi çıkartılamıyor</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Aygıt meşgul, şimdi çıkarılamıyor</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Aygıt meşgul, şimdi çıkarılamaz</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Birim</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Bilinmiyor</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Cihaz güvenli bir şekilde kaldırılmadı</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Bir daha ki sefer &quot;Güvenle Kaldıra&quot; tıklayın bağlantısını kesin</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Aygıtın bağı ayrılamadı</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Diski &quot;%1&quot; kullanıcısı bağlamış, siz bu bağı ayıramazsınız.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Takılı aygıt bulunamıyor</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Diskler</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Tümünü çıkar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Cihaz güvenli bir şekilde kaldırıldı</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Erişim reddedildi</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Bu klasöre erişme izniniz yok</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Cihaz taranıyor, durdurulsun mu?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Onayla</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Durdur</translation>
    </message>
</context>
</TS>
